@@ -10,7 +10,8 @@
 #' @importFrom methods new
 #' @importFrom sp coordinates SpatialPolygons Polygons Polygon CRS proj4string
 #'  SpatialPolygonsDataFrame
-#' @importFrom dplyr %>% summarise_ group_by summarise_at
+#' @importFrom dplyr %>% summarise group_by summarise_at
+#' @importFrom rlang parse_exprs
 #' @details
 #' Given a set of points a varying size Quadtree grid is created performing a
 #' bottom-up aggregation considering a minimum threshold for each cell.
@@ -220,8 +221,8 @@ createAQuadtree <- function(points, dim=1000, layers=5, colnames=NULL, threshold
   pts[c("x", "y", "CellOrigin.x", "CellOrigin.y")]<-NULL
   pts$cellCodesStr<-paste0(pts$cellCode, pts$cellNum)
   ## message("layer:1\n")
-  prevGrid <- pts %>% group_by(cellCode) %>% summarise_(.dots=summariseExpr)
-
+  prevGrid <- pts %>% group_by(cellCode) %>% summarise(!!!parse_exprs(summariseExpr))
+  
   prevGrid<-prevGrid[apply(prevGrid[,thresholdField]>=threshold,1, all),]   # remove high level cells with underthreshold population
   if (nrow(prevGrid)==0) stop("empty set, try a smaller threshold", call.="FALSE")
   prevGrid$level<-1
@@ -238,7 +239,7 @@ createAQuadtree <- function(points, dim=1000, layers=5, colnames=NULL, threshold
     actualcellNumPos<-cellNumPosStop[i]
     pts$cellCode<-substr(pts$cellCodesStr, 1, cellNumPosStop[i])
 
-    actualGrid <- pts %>% group_by(cellCode) %>% summarise_(.dots=summariseExpr)
+    actualGrid <- pts %>% group_by(cellCode) %>% summarise(!!!parse_exprs(summariseExpr))
     actualGrid$level<-i
     maxLayer<-i
     actualGrid$ContainerID<-substr(actualGrid$cellCode, 1, cellNumPosStop[i-1])
@@ -293,7 +294,7 @@ createAQuadtree <- function(points, dim=1000, layers=5, colnames=NULL, threshold
     removed.Points$cellCode<-substr(removed.Points$cellCode, 1, cellNumPosStop[1])
     removed.Points$ContainerID<-NULL
 
-    removed.Points<-removed.Points %>% group_by(cellCode) %>% summarise_(.dots=summariseExpr)
+    removed.Points<-removed.Points %>% group_by(cellCode) %>% summarise(!!!parse_exprs(summariseExpr))
     ## keep only aggregation of removed point over the threshold value
     removed.Points<-removed.Points[apply(removed.Points[thresholdField]>=threshold, 1, all),]
     if (nrow(removed.Points)>0) {
